#[non_exhaustive]pub struct Application {
pub name: String,
pub display_name: String,
pub description: String,
pub attributes: Option<Attributes>,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub scope: Option<Scope>,
pub uid: String,
pub state: State,
/* private fields */
}Expand description
Application defines the governance boundary for App Hub entities that perform a logical end-to-end business function. App Hub supports application level IAM permission to align with governance requirements.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of an Application. Format:
"projects/{host-project-id}/locations/{location}/applications/{application-id}"
display_name: StringOptional. User-defined name for the Application. Can have a maximum length of 63 characters.
description: StringOptional. User-defined description of an Application. Can have a maximum length of 2048 characters.
attributes: Option<Attributes>Optional. Consumer provided attributes.
create_time: Option<Timestamp>Output only. Create time.
update_time: Option<Timestamp>Output only. Update time.
scope: Option<Scope>Required. Immutable. Defines what data can be included into this Application. Limits which Services and Workloads can be registered.
uid: StringOutput only. A universally unique identifier (in UUID4 format) for the
Application.
state: StateOutput only. Application state.
Implementations
Sourceimpl Application
impl Application
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_attributes<T>(self, v: T) -> Selfwhere
T: Into<Attributes>,
pub fn set_attributes<T>(self, v: T) -> Selfwhere
T: Into<Attributes>,
Sets the value of attributes.
Example
use google_cloud_apphub_v1::model::Attributes;
let x = Application::new().set_attributes(Attributes::default()/* use setters */);Sourcepub fn set_or_clear_attributes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Attributes>,
pub fn set_or_clear_attributes<T>(self, v: Option<T>) -> Selfwhere
T: Into<Attributes>,
Sets or clears the value of attributes.
Example
use google_cloud_apphub_v1::model::Attributes;
let x = Application::new().set_or_clear_attributes(Some(Attributes::default()/* use setters */));
let x = Application::new().set_or_clear_attributes(None::<Attributes>);Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Application::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Application::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Application::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Application::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Application::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Application::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_or_clear_scope<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_scope<T>(self, v: Option<T>) -> Self