#[non_exhaustive]pub struct CreateApplicationRequest {
pub parent: String,
pub application_id: String,
pub application: Option<Application>,
pub request_id: String,
/* private fields */
}Expand description
Request for CreateApplication.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Project and location to create Application in.
Expected format: projects/{project}/locations/{location}.
application_id: StringRequired. The Application identifier. Must contain only lowercase letters, numbers or hyphens, with the first character a letter, the last a letter or a number, and a 63 character maximum.
application: Option<Application>Required. The resource being created
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateApplicationRequest
impl CreateApplicationRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_application_id<T: Into<String>>(self, v: T) -> Self
pub fn set_application_id<T: Into<String>>(self, v: T) -> Self
Sets the value of application_id.
Example
let x = CreateApplicationRequest::new().set_application_id("example");Sourcepub fn set_application<T>(self, v: T) -> Selfwhere
T: Into<Application>,
pub fn set_application<T>(self, v: T) -> Selfwhere
T: Into<Application>,
Sets the value of application.
Example
use google_cloud_apphub_v1::model::Application;
let x = CreateApplicationRequest::new().set_application(Application::default()/* use setters */);Sourcepub fn set_or_clear_application<T>(self, v: Option<T>) -> Selfwhere
T: Into<Application>,
pub fn set_or_clear_application<T>(self, v: Option<T>) -> Selfwhere
T: Into<Application>,
Sets or clears the value of application.
Example
use google_cloud_apphub_v1::model::Application;
let x = CreateApplicationRequest::new().set_or_clear_application(Some(Application::default()/* use setters */));
let x = CreateApplicationRequest::new().set_or_clear_application(None::<Application>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateApplicationRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateApplicationRequest
impl Clone for CreateApplicationRequest
Sourcefn clone(&self) -> CreateApplicationRequest
fn clone(&self) -> CreateApplicationRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateApplicationRequest
impl Debug for CreateApplicationRequest
Sourceimpl Default for CreateApplicationRequest
impl Default for CreateApplicationRequest
Sourcefn default() -> CreateApplicationRequest
fn default() -> CreateApplicationRequest
Sourceimpl Message for CreateApplicationRequest
impl Message for CreateApplicationRequest
Sourceimpl PartialEq for CreateApplicationRequest
impl PartialEq for CreateApplicationRequest
impl StructuralPartialEq for CreateApplicationRequest