#[non_exhaustive]pub struct CreateServiceProjectAttachmentRequest {
pub parent: String,
pub service_project_attachment_id: String,
pub service_project_attachment: Option<ServiceProjectAttachment>,
pub request_id: String,
/* private fields */
}Expand description
Request for CreateServiceProjectAttachment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Host project ID and location to which service project is being
attached. Only global location is supported. Expected format:
projects/{project}/locations/{location}.
service_project_attachment_id: StringRequired. The service project attachment identifier must contain the project id of the service project specified in the service_project_attachment.service_project field.
service_project_attachment: Option<ServiceProjectAttachment>Required. The resource being created.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateServiceProjectAttachmentRequest
impl CreateServiceProjectAttachmentRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_service_project_attachment_id<T: Into<String>>(self, v: T) -> Self
pub fn set_service_project_attachment_id<T: Into<String>>(self, v: T) -> Self
Sets the value of service_project_attachment_id.
Example
let x = CreateServiceProjectAttachmentRequest::new().set_service_project_attachment_id("example");Sourcepub fn set_service_project_attachment<T>(self, v: T) -> Selfwhere
T: Into<ServiceProjectAttachment>,
pub fn set_service_project_attachment<T>(self, v: T) -> Selfwhere
T: Into<ServiceProjectAttachment>,
Sets the value of service_project_attachment.
Example
use google_cloud_apphub_v1::model::ServiceProjectAttachment;
let x = CreateServiceProjectAttachmentRequest::new().set_service_project_attachment(ServiceProjectAttachment::default()/* use setters */);Sourcepub fn set_or_clear_service_project_attachment<T>(self, v: Option<T>) -> Selfwhere
T: Into<ServiceProjectAttachment>,
pub fn set_or_clear_service_project_attachment<T>(self, v: Option<T>) -> Selfwhere
T: Into<ServiceProjectAttachment>,
Sets or clears the value of service_project_attachment.
Example
use google_cloud_apphub_v1::model::ServiceProjectAttachment;
let x = CreateServiceProjectAttachmentRequest::new().set_or_clear_service_project_attachment(Some(ServiceProjectAttachment::default()/* use setters */));
let x = CreateServiceProjectAttachmentRequest::new().set_or_clear_service_project_attachment(None::<ServiceProjectAttachment>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateServiceProjectAttachmentRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateServiceProjectAttachmentRequest
impl Clone for CreateServiceProjectAttachmentRequest
Sourcefn clone(&self) -> CreateServiceProjectAttachmentRequest
fn clone(&self) -> CreateServiceProjectAttachmentRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for CreateServiceProjectAttachmentRequest
impl Default for CreateServiceProjectAttachmentRequest
Sourcefn default() -> CreateServiceProjectAttachmentRequest
fn default() -> CreateServiceProjectAttachmentRequest
impl StructuralPartialEq for CreateServiceProjectAttachmentRequest