#[non_exhaustive]pub struct CreateServiceRequest {
pub parent: String,
pub service_id: String,
pub service: Option<Service>,
pub request_id: String,
/* private fields */
}Expand description
Request for CreateService.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Fully qualified name of the parent Application to create the
Service in. Expected format:
projects/{project}/locations/{location}/applications/{application}.
service_id: StringRequired. The Service identifier. Must contain only lowercase letters, numbers or hyphens, with the first character a letter, the last a letter or a number, and a 63 character maximum.
service: Option<Service>Required. The resource being created.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateServiceRequest
impl CreateServiceRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_service_id<T: Into<String>>(self, v: T) -> Self
pub fn set_service_id<T: Into<String>>(self, v: T) -> Self
Sets the value of service_id.
Example
let x = CreateServiceRequest::new().set_service_id("example");Sourcepub fn set_service<T>(self, v: T) -> Self
pub fn set_service<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_service<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_service<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateServiceRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateServiceRequest
impl Clone for CreateServiceRequest
Sourcefn clone(&self) -> CreateServiceRequest
fn clone(&self) -> CreateServiceRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateServiceRequest
impl Debug for CreateServiceRequest
Sourceimpl Default for CreateServiceRequest
impl Default for CreateServiceRequest
Sourcefn default() -> CreateServiceRequest
fn default() -> CreateServiceRequest
Sourceimpl Message for CreateServiceRequest
impl Message for CreateServiceRequest
Sourceimpl PartialEq for CreateServiceRequest
impl PartialEq for CreateServiceRequest
impl StructuralPartialEq for CreateServiceRequest