#[non_exhaustive]pub struct CreateWorkloadRequest {
pub parent: String,
pub workload_id: String,
pub workload: Option<Workload>,
pub request_id: String,
/* private fields */
}Expand description
Request for CreateWorkload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Fully qualified name of the Application to create Workload in.
Expected format:
projects/{project}/locations/{location}/applications/{application}.
workload_id: StringRequired. The Workload identifier. Must contain only lowercase letters, numbers or hyphens, with the first character a letter, the last a letter or a number, and a 63 character maximum.
workload: Option<Workload>Required. The resource being created.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateWorkloadRequest
impl CreateWorkloadRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_workload_id<T: Into<String>>(self, v: T) -> Self
pub fn set_workload_id<T: Into<String>>(self, v: T) -> Self
Sets the value of workload_id.
Example
let x = CreateWorkloadRequest::new().set_workload_id("example");Sourcepub fn set_workload<T>(self, v: T) -> Self
pub fn set_workload<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_workload<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_workload<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateWorkloadRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateWorkloadRequest
impl Clone for CreateWorkloadRequest
Sourcefn clone(&self) -> CreateWorkloadRequest
fn clone(&self) -> CreateWorkloadRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateWorkloadRequest
impl Debug for CreateWorkloadRequest
Sourceimpl Default for CreateWorkloadRequest
impl Default for CreateWorkloadRequest
Sourcefn default() -> CreateWorkloadRequest
fn default() -> CreateWorkloadRequest
Sourceimpl Message for CreateWorkloadRequest
impl Message for CreateWorkloadRequest
Sourceimpl PartialEq for CreateWorkloadRequest
impl PartialEq for CreateWorkloadRequest
impl StructuralPartialEq for CreateWorkloadRequest