#[non_exhaustive]pub struct DiscoveredService {
pub name: String,
pub service_reference: Option<ServiceReference>,
pub service_properties: Option<ServiceProperties>,
/* private fields */
}Expand description
DiscoveredService is a network or API interface that exposes some functionality to clients for consumption over the network. A discovered service can be registered to a App Hub service.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of the discovered service. Format:
"projects/{host-project-id}/locations/{location}/discoveredServices/{uuid}"
service_reference: Option<ServiceReference>Output only. Reference to an underlying networking resource that can comprise a Service. These are immutable.
service_properties: Option<ServiceProperties>Output only. Properties of an underlying compute resource that can comprise a Service. These are immutable.
Implementations
Sourceimpl DiscoveredService
impl DiscoveredService
Sourcepub fn set_service_reference<T>(self, v: T) -> Selfwhere
T: Into<ServiceReference>,
pub fn set_service_reference<T>(self, v: T) -> Selfwhere
T: Into<ServiceReference>,
Sets the value of service_reference.
Example
ⓘ
use google_cloud_apphub_v1::model::ServiceReference;
let x = DiscoveredService::new().set_service_reference(ServiceReference::default()/* use setters */);Sourcepub fn set_or_clear_service_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<ServiceReference>,
pub fn set_or_clear_service_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<ServiceReference>,
Sets or clears the value of service_reference.
Example
ⓘ
use google_cloud_apphub_v1::model::ServiceReference;
let x = DiscoveredService::new().set_or_clear_service_reference(Some(ServiceReference::default()/* use setters */));
let x = DiscoveredService::new().set_or_clear_service_reference(None::<ServiceReference>);Sourcepub fn set_service_properties<T>(self, v: T) -> Selfwhere
T: Into<ServiceProperties>,
pub fn set_service_properties<T>(self, v: T) -> Selfwhere
T: Into<ServiceProperties>,
Sets the value of service_properties.
Example
ⓘ
use google_cloud_apphub_v1::model::ServiceProperties;
let x = DiscoveredService::new().set_service_properties(ServiceProperties::default()/* use setters */);Sourcepub fn set_or_clear_service_properties<T>(self, v: Option<T>) -> Selfwhere
T: Into<ServiceProperties>,
pub fn set_or_clear_service_properties<T>(self, v: Option<T>) -> Selfwhere
T: Into<ServiceProperties>,
Sets or clears the value of service_properties.
Example
ⓘ
use google_cloud_apphub_v1::model::ServiceProperties;
let x = DiscoveredService::new().set_or_clear_service_properties(Some(ServiceProperties::default()/* use setters */));
let x = DiscoveredService::new().set_or_clear_service_properties(None::<ServiceProperties>);Trait Implementations
Sourceimpl Clone for DiscoveredService
impl Clone for DiscoveredService
Sourcefn clone(&self) -> DiscoveredService
fn clone(&self) -> DiscoveredService
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DiscoveredService
impl Debug for DiscoveredService
Sourceimpl Default for DiscoveredService
impl Default for DiscoveredService
Sourcefn default() -> DiscoveredService
fn default() -> DiscoveredService
Returns the “default value” for a type. Read more
Sourceimpl Message for DiscoveredService
impl Message for DiscoveredService
Sourceimpl PartialEq for DiscoveredService
impl PartialEq for DiscoveredService
impl StructuralPartialEq for DiscoveredService