#[non_exhaustive]pub struct DiscoveredWorkload {
pub name: String,
pub workload_reference: Option<WorkloadReference>,
pub workload_properties: Option<WorkloadProperties>,
/* private fields */
}Expand description
DiscoveredWorkload is a binary deployment (such as managed instance groups (MIGs) and GKE deployments) that performs the smallest logical subset of business functionality. A discovered workload can be registered to an App Hub Workload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of the discovered workload. Format:
"projects/{host-project-id}/locations/{location}/discoveredWorkloads/{uuid}"
workload_reference: Option<WorkloadReference>Output only. Reference of an underlying compute resource represented by the Workload. These are immutable.
workload_properties: Option<WorkloadProperties>Output only. Properties of an underlying compute resource represented by the Workload. These are immutable.
Implementations
Sourceimpl DiscoveredWorkload
impl DiscoveredWorkload
Sourcepub fn set_workload_reference<T>(self, v: T) -> Selfwhere
T: Into<WorkloadReference>,
pub fn set_workload_reference<T>(self, v: T) -> Selfwhere
T: Into<WorkloadReference>,
Sets the value of workload_reference.
Example
use google_cloud_apphub_v1::model::WorkloadReference;
let x = DiscoveredWorkload::new().set_workload_reference(WorkloadReference::default()/* use setters */);Sourcepub fn set_or_clear_workload_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<WorkloadReference>,
pub fn set_or_clear_workload_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<WorkloadReference>,
Sets or clears the value of workload_reference.
Example
use google_cloud_apphub_v1::model::WorkloadReference;
let x = DiscoveredWorkload::new().set_or_clear_workload_reference(Some(WorkloadReference::default()/* use setters */));
let x = DiscoveredWorkload::new().set_or_clear_workload_reference(None::<WorkloadReference>);Sourcepub fn set_workload_properties<T>(self, v: T) -> Selfwhere
T: Into<WorkloadProperties>,
pub fn set_workload_properties<T>(self, v: T) -> Selfwhere
T: Into<WorkloadProperties>,
Sets the value of workload_properties.
Example
use google_cloud_apphub_v1::model::WorkloadProperties;
let x = DiscoveredWorkload::new().set_workload_properties(WorkloadProperties::default()/* use setters */);Sourcepub fn set_or_clear_workload_properties<T>(self, v: Option<T>) -> Selfwhere
T: Into<WorkloadProperties>,
pub fn set_or_clear_workload_properties<T>(self, v: Option<T>) -> Selfwhere
T: Into<WorkloadProperties>,
Sets or clears the value of workload_properties.
Example
use google_cloud_apphub_v1::model::WorkloadProperties;
let x = DiscoveredWorkload::new().set_or_clear_workload_properties(Some(WorkloadProperties::default()/* use setters */));
let x = DiscoveredWorkload::new().set_or_clear_workload_properties(None::<WorkloadProperties>);Trait Implementations
Sourceimpl Clone for DiscoveredWorkload
impl Clone for DiscoveredWorkload
Sourcefn clone(&self) -> DiscoveredWorkload
fn clone(&self) -> DiscoveredWorkload
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DiscoveredWorkload
impl Debug for DiscoveredWorkload
Sourceimpl Default for DiscoveredWorkload
impl Default for DiscoveredWorkload
Sourcefn default() -> DiscoveredWorkload
fn default() -> DiscoveredWorkload
Sourceimpl Message for DiscoveredWorkload
impl Message for DiscoveredWorkload
Sourceimpl PartialEq for DiscoveredWorkload
impl PartialEq for DiscoveredWorkload
impl StructuralPartialEq for DiscoveredWorkload