#[non_exhaustive]pub struct ListWorkloadsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
/* private fields */
}Expand description
Request for ListWorkloads.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Fully qualified name of the parent Application to list Workloads
for. Expected format:
projects/{project}/locations/{location}/applications/{application}.
page_size: i32Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.
page_token: StringOptional. A token identifying a page of results the server should return.
filter: StringOptional. Filtering results.
order_by: StringOptional. Hint for how to order the results.
Implementations
Sourceimpl ListWorkloadsRequest
impl ListWorkloadsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListWorkloadsRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self