#[non_exhaustive]pub struct ServiceProjectAttachment {
pub name: String,
pub service_project: String,
pub create_time: Option<Timestamp>,
pub uid: String,
pub state: State,
/* private fields */
}Expand description
ServiceProjectAttachment represents an attachment from a service project to a host project. Service projects contain the underlying cloud infrastructure resources, and expose these resources to the host project through a ServiceProjectAttachment. With the attachments, the host project can provide an aggregated view of resources across all service projects.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of a ServiceProjectAttachment. Format:
"projects/{host-project-id}/locations/global/serviceProjectAttachments/{service-project-id}."
service_project: StringRequired. Immutable. Service project name in the format: "projects/abc"
or "projects/123". As input, project name with either project id or
number are accepted. As output, this field will contain project number.
create_time: Option<Timestamp>Output only. Create time.
uid: StringOutput only. A globally unique identifier (in UUID4 format) for the
ServiceProjectAttachment.
state: StateOutput only. ServiceProjectAttachment state.
Implementations
Sourceimpl ServiceProjectAttachment
impl ServiceProjectAttachment
Sourcepub fn set_service_project<T: Into<String>>(self, v: T) -> Self
pub fn set_service_project<T: Into<String>>(self, v: T) -> Self
Sets the value of service_project.
Example
let x = ServiceProjectAttachment::new().set_service_project("example");Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = ServiceProjectAttachment::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = ServiceProjectAttachment::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = ServiceProjectAttachment::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_state<T: Into<State>>(self, v: T) -> Self
pub fn set_state<T: Into<State>>(self, v: T) -> Self
Sets the value of state.
Example
use google_cloud_apphub_v1::model::service_project_attachment::State;
let x0 = ServiceProjectAttachment::new().set_state(State::Creating);
let x1 = ServiceProjectAttachment::new().set_state(State::Active);
let x2 = ServiceProjectAttachment::new().set_state(State::Deleting);Trait Implementations
Sourceimpl Clone for ServiceProjectAttachment
impl Clone for ServiceProjectAttachment
Sourcefn clone(&self) -> ServiceProjectAttachment
fn clone(&self) -> ServiceProjectAttachment
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ServiceProjectAttachment
impl Debug for ServiceProjectAttachment
Sourceimpl Default for ServiceProjectAttachment
impl Default for ServiceProjectAttachment
Sourcefn default() -> ServiceProjectAttachment
fn default() -> ServiceProjectAttachment
Sourceimpl Message for ServiceProjectAttachment
impl Message for ServiceProjectAttachment
Sourceimpl PartialEq for ServiceProjectAttachment
impl PartialEq for ServiceProjectAttachment
impl StructuralPartialEq for ServiceProjectAttachment