#[non_exhaustive]pub struct UpdateApplicationRequest {
pub update_mask: Option<FieldMask>,
pub application: Option<Application>,
pub request_id: String,
/* private fields */
}Expand description
Request for UpdateApplication.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Required. Field mask is used to specify the fields to be overwritten in the Application resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. The API changes the values of the fields as specified in the update_mask. The API ignores the values of all fields not covered by the update_mask. You can also unset a field by not specifying it in the updated message, but adding the field to the mask. This clears whatever value the field previously had.
application: Option<Application>Required. The resource being updated.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl UpdateApplicationRequest
impl UpdateApplicationRequest
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateApplicationRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateApplicationRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateApplicationRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_application<T>(self, v: T) -> Selfwhere
T: Into<Application>,
pub fn set_application<T>(self, v: T) -> Selfwhere
T: Into<Application>,
Sets the value of application.
Example
use google_cloud_apphub_v1::model::Application;
let x = UpdateApplicationRequest::new().set_application(Application::default()/* use setters */);Sourcepub fn set_or_clear_application<T>(self, v: Option<T>) -> Selfwhere
T: Into<Application>,
pub fn set_or_clear_application<T>(self, v: Option<T>) -> Selfwhere
T: Into<Application>,
Sets or clears the value of application.
Example
use google_cloud_apphub_v1::model::Application;
let x = UpdateApplicationRequest::new().set_or_clear_application(Some(Application::default()/* use setters */));
let x = UpdateApplicationRequest::new().set_or_clear_application(None::<Application>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = UpdateApplicationRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for UpdateApplicationRequest
impl Clone for UpdateApplicationRequest
Sourcefn clone(&self) -> UpdateApplicationRequest
fn clone(&self) -> UpdateApplicationRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for UpdateApplicationRequest
impl Debug for UpdateApplicationRequest
Sourceimpl Default for UpdateApplicationRequest
impl Default for UpdateApplicationRequest
Sourcefn default() -> UpdateApplicationRequest
fn default() -> UpdateApplicationRequest
Sourceimpl Message for UpdateApplicationRequest
impl Message for UpdateApplicationRequest
Sourceimpl PartialEq for UpdateApplicationRequest
impl PartialEq for UpdateApplicationRequest
impl StructuralPartialEq for UpdateApplicationRequest