#[non_exhaustive]pub struct WorkloadProperties {
pub gcp_project: String,
pub location: String,
pub zone: String,
/* private fields */
}Expand description
Properties of an underlying compute resource represented by the Workload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.gcp_project: StringOutput only. The service project identifier that the underlying cloud resource resides in. Empty for non-cloud resources.
location: StringOutput only. The location that the underlying compute resource resides in (for example, us-west1).
zone: StringOutput only. The location that the underlying compute resource resides in if it is zonal (for example, us-west1-a).
Implementations
Sourceimpl WorkloadProperties
impl WorkloadProperties
Sourcepub fn set_gcp_project<T: Into<String>>(self, v: T) -> Self
pub fn set_gcp_project<T: Into<String>>(self, v: T) -> Self
Sets the value of gcp_project.
Example
ⓘ
let x = WorkloadProperties::new().set_gcp_project("example");Sourcepub fn set_location<T: Into<String>>(self, v: T) -> Self
pub fn set_location<T: Into<String>>(self, v: T) -> Self